==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/nb.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar \"%s\"" : "%s har publisert kalenderen \"%s\"",
    "Too many redirects. Aborting ..." : "For mange viderekoblinger. Avbryter...",
    "Error connecting to remote server" : "Feil ved opprettelsen av forbindelse til tjeneren",
    "Individual" : "Individuel",
    "Group" : "Gruppe",
    "Resource" : "Ressurs",
    "Room" : "Rom",
    "Unknown" : "Ukjent",
    "Required" : "Påkrevet",
    "Optional" : "Valgfri",
    "Does not attend" : "Deltar ikke",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukjent tidssone ({tz}), faller tilbake til UTC",
    "Please create a calendar first." : "Vennligst opprett en kalender først",
    "New event" : "Ny hendelse",
    "CalDAV address for clients" : "CalDAV adresse for klienter",
    "Error saving WebCal-calendar" : "Feil under lagring av WebCal-kalender",
    "EMail has been sent." : "E-post er sendt",
    "There was an issue while sending your EMail." : "Problem ved sending av din epost.",
    "group" : "gruppe",
    "Details" : "Detaljer",
    "Attendees" : "Deltakere",
    "Reminders" : "Varsler",
    "Repeating" : "Gjentas",
    "When shared show full event" : "Vis hele hendelsen når delt",
    "When shared show only busy" : "Vis kun opptatt når delt",
    "When shared hide this event" : "Skjul denne hendelsen når delt",
    "Confirmed" : "Bekreftet",
    "Tentative" : "Foreløpig",
    "Cancelled" : "Avbrutt",
    "Please add a title!" : "Vennligst lag en tittel!",
    "Please select a calendar!" : "Vennligst velg en kalender!",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Hver dag",
    "Every week" : "Hver uke",
    "Every month" : "Hver måned",
    "Every year" : "Hvert år",
    "never" : "aldri",
    "after" : "etter",
    "How about getting started by importing some calendars?" : "Hva med å starte import av noen kalendere?",
    "At time of event" : "Ved tiden for hendelsen",
    "5 minutes before" : "5 minutter før",
    "10 minutes before" : "10 minutter før",
    "15 minutes before" : "15 minutter før",
    "30 minutes before" : "30 minutter før",
    "1 hour before" : "1 time før",
    "2 hours before" : "2 timer før",
    "Custom" : "Tilpasset",
    "Audio" : "Lyd",
    "E Mail" : "E-post",
    "Pop up" : "Oppsprett",
    "sec" : "sek",
    "min" : "min",
    "hours" : "timer",
    "days" : "dager",
    "week" : "uke",
    "before" : "før",
    "start" : "start",
    "end" : "slutt",
    "Editing reminders of unknown type not supported." : "Redigering av varsler av ukjent type støttes ikke.",
    "Week {number} of {year}" : "Uke {number} {year}",
    "Successfully imported" : "Vellykket importert",
    "Partially imported, 1 failure" : "Delvis importert, 1 feil",
    "Partially imported, {n} failures" : "Delvis importert, {n} feil",
    "Audio alarm" : "Lydsignal",
    "Pop-up" : "Oppsprett",
    "E-Mail" : "E-post",
    "{type} {time} before the event starts" : "{type} {time} før hendelsen starter",
    "{type} {time} before the event ends" : "{type} {time} før hendelsen slutter",
    "{type} {time} after the event starts" : "{type} {time} etter hendelsen starter",
    "{type} {time} after the event ends" : "{type} {time} etter hendelsen slutter",
    "{type} at the event's start" : "{type} ved hendelsens start",
    "{type} at the event's end" : "{type} ved hendelsens slutt",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} delt av {owner}",
    "Please enter a valid WebCal-URL" : "Vennligst oppgi en WebCal-URL",
    "Title of the Event" : "Tittel for hendelsen",
    "starts" : "starter",
    "ends" : "slutter",
    "All day Event" : "Heldagshendelse",
    "Delete" : "Slett",
    "Cancel" : "Avbryt",
    "More ..." : "Mer ...",
    "Create" : "Opprett",
    "Update" : "Oppdater",
    "Close" : "Lukk",
    "Location" : "Sted",
    "Description" : "Beskrivelse",
    "Event status" : "Hendelse status",
    "Visibility when sharing" : "Synlighet ved deling",
    "Export" : "Eksporter",
    "%s has published the calendar %s" : "%s har publisert kalenderen %s",
    "Hello," : "Hei,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønsker å informere deg om at %s har publisert kalenderen {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikk her for å åpne den",
    "Cheers!" : "Ha det!",
    "We wanted to inform you that %s has published the calendar %s." : "Vi ønsker å informere deg om at %s har publisert kalenderen %s.",
    "Click on the link below to access it" : "Klikk på lenken under for å åpne den.",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Pga. en feil oppstrøms, støtter kalenderen for tiden ikke \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt administratoren og be dem deaktivere valget \"asset-pipeline.enabled\" i konfigurasjonen.",
    "Day" : "Dag",
    "Week" : "Uke",
    "Month" : "Måned",
    "Today" : "I dag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Noen hendelser i kalenderen er ødelagt. Vennligst sjekk JS konsollet for mer info.",
    "Share Calendar" : "Del kalender",
    "Shared" : "Delt",
    "More" : "Mer",
    "Edit" : "Endre",
    "Link" : "Lenke",
    "iCal link" : "iCal lenke",
    "Download" : "Last ned",
    "Share with users or groups" : "Del med brukere eller grupper",
    "can edit" : "kan endre",
    "Share link" : "Del lenke",
    "Public access" : "Offentlig tilgang",
    "Email link to person" : "Email lenke til person",
    "Send" : "Send",
    "New Calendar" : "Ny kalender",
    "Name" : "Navn",
    "New Subscription" : "Nytt abonnement",
    "Go back" : "Gå tilbake",
    "Go forward" : "Gå frem",
    "Edit event" : "Rediger hendelse",
    "Delete Event" : "Slett hendelse",
    "Save Event" : "Lagre hendelse",
    "Time" : "Tid",
    "Type" : "Type",
    "Relative" : "Relativ",
    "Absolute" : "Absolutt",
    "Repeat" : "Gjenta",
    "times every" : "ganger hver",
    "Add" : "Legg til",
    "E-Mail address of attendee" : "E-postadresse for deltaker",
    "Please add your email address in the personal settings in order to add attendees." : "Vennligst legg inn epost-adressen din i personlige innstillinger for å kunne legge til deltakere.",
    "from" : "fra",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Hendelsens regel for gjentagelse støttes ikke ennå.",
    "Support for advanced rules will be added with subsequent updates." : "Støtte for avanserte regler blir lagt til i senere oppdateringer.",
    "Reset repeating rule" : "Nullstill gjentaksregel",
    "Repeat every ..." : "Gjenta hver ...",
    "end repeat ..." : "avslutt gjentak ...",
    "times" : "ganger",
    "Import Calendars" : "Importerer kalendre",
    "Import canceled" : "Import avbrutt",
    "Analyzing calendar" : "Analyserer kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen inneholder objekter som ikke passer sammen med den valgte kalenderen",
    "New calendar" : "Ny kalender",
    "File is empty" : "Filen er tom",
    "Import scheduled" : "Importer planlagte",
    "Subscribe & embed" : "Abonnér og inkluder",
    "Publish URL" : "Offentlig URL",
    "Iframe to integrate" : "Iframe du vil integrere",
    "Settings & import" : "Innstillinger og import",
    "Skip simple event editor" : "Hopp over enkelt hendelsesredigering",
    "Show week numbers" : "Vis ukenumre",
    "Import calendar" : "Importer kalender",
    "No Calendars selected for import" : "Ingen kalendre valgt for import",
    "Primary CalDAV address" : "Primær CalDAV-adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/nb.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar \"%s\"" : "%s har publisert kalenderen \"%s\"",
    "Too many redirects. Aborting ..." : "For mange videresendinger. Avbryter…",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ekstern tjener nektet tilgang til kalenderen (HTTP {%s} error)",
    "Error connecting to remote server" : "Feil ved opprettelsen av forbindelse til tjeneren",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Feil ved forespørsel om ressurser på ekstern tjener. Dette er trolig relatert til sertifikatavvik.",
    "Error requesting resource on remote server" : "Feil ved forespørsel om ressurs på ekstern tjener",
    "Individual" : "Individuell",
    "Group" : "Gruppe",
    "Resource" : "Ressurs",
    "Room" : "Rom",
    "Unknown" : "Ukjent",
    "Required" : "Påkrevd",
    "Optional" : "Valgfri",
    "Does not attend" : "Deltar ikke",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukjent tidssone ({tz}), bruker UTC",
    "Please create a calendar first." : "Opprett en kalender først",
    "New event" : "Ny hendelse",
    "CalDAV address for clients" : "CalDAV adresse for klienter",
    "Error saving WebCal-calendar" : "Feil under lagring av WebCal-kalender",
    "WebDAV address for subscriptions" : "WebDAV-adresse for abonnementer",
    "EMail has been sent." : "E-post er sendt",
    "There was an issue while sending your EMail." : "Problem ved forsendelse av din e-post.",
    "group" : "gruppe",
    "Details" : "Detaljer",
    "Attendees" : "Deltakere",
    "Reminders" : "Varsler",
    "Repeating" : "Gjentas",
    "When shared show full event" : "Vis hele hendelsen når delt",
    "When shared show only busy" : "Vis kun opptatt når delt",
    "When shared hide this event" : "Skjul denne hendelsen når delt",
    "Confirmed" : "Bekreftet",
    "Tentative" : "Foreløpig",
    "Cancelled" : "Avbrutt",
    "Please add a title!" : "Legg til en tittel!",
    "Please select a calendar!" : "Velg en kalender.",
    "The event ends before it starts!" : "Hendelsen slutter før den starter!",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Hver dag",
    "Every week" : "Hver uke",
    "Every month" : "Hver måned",
    "Every year" : "Hvert år",
    "never" : "aldri",
    "after" : "etter",
    "How about getting started by importing some calendars?" : "Hva med å starte import av noen kalendere?",
    "At time of event" : "Ved tiden for hendelsen",
    "5 minutes before" : "5 minutter før",
    "10 minutes before" : "10 minutter før",
    "15 minutes before" : "15 minutter før",
    "30 minutes before" : "30 minutter før",
    "1 hour before" : "1 time før",
    "2 hours before" : "2 timer før",
    "Custom" : "Brukervalgt",
    "Audio" : "Lyd",
    "E Mail" : "E-post",
    "Pop up" : "Oppsprett",
    "sec" : "sek",
    "min" : "min",
    "hours" : "timer",
    "days" : "dager",
    "week" : "uke",
    "before" : "før",
    "start" : "start",
    "end" : "slutt",
    "Editing reminders of unknown type not supported." : "Redigering av varsler av ukjent type støttes ikke.",
    "Week {number} of {year}" : "Uke {number} {year}",
    "Successfully imported" : "Importert",
    "Partially imported, 1 failure" : "Delvis importert, 1 feil",
    "Partially imported, {n} failures" : "Delvis importert, {n} feil",
    "Audio alarm" : "Lydsignal",
    "Pop-up" : "Oppsprett",
    "E-Mail" : "E-post",
    "{type} {time} before the event starts" : "{type} {time} før hendelsen starter",
    "{type} {time} before the event ends" : "{type} {time} før hendelsen slutter",
    "{type} {time} after the event starts" : "{type} {time} etter hendelsen starter",
    "{type} {time} after the event ends" : "{type} {time} etter hendelsen slutter",
    "{type} at the event's start" : "{type} ved hendelsens start",
    "{type} at the event's end" : "{type} ved hendelsens slutt",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} delt av {owner}",
    "Please enter a valid WebCal-URL" : "Oppgi en WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Tjenerfeil i WebCal-mellomtjener. Kontakt administrator for mer informasjon.",
    "Title of the Event" : "Tittel for hendelsen",
    "Starts" : "Begynner",
    "Ends" : "Slutter",
    "All day Event" : "Heldagshendelse",
    "Delete" : "Slett",
    "Cancel" : "Avbryt",
    "More ..." : "Mer…",
    "Create" : "Opprett",
    "Update" : "Oppdater",
    "Close" : "Lukk",
    "Location" : "Sted",
    "Description" : "Beskrivelse",
    "Event status" : "Hendelse status",
    "Visibility when sharing" : "Synlighet ved deling",
    "Export" : "Eksporter",
    "%s has published the calendar %s" : "%s har publisert kalenderen %s",
    "Hello," : "Hei,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønsker å informere deg om at %s har publisert kalenderen {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikk her for å åpne den",
    "Cheers!" : "Ha det!",
    "We wanted to inform you that %s has published the calendar %s." : "Vi ønsker å informere deg om at %s har publisert kalenderen %s.",
    "Click on the link below to access it" : "Klikk på lenken under for å åpne den.",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Pga. en feil oppstrøms, støtter kalenderen for tiden ikke \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt administratoren og be dem skru av valget \"asset-pipeline.enabled\" i oppsettet.",
    "Day" : "Dag",
    "Week" : "Uke",
    "Month" : "Måned",
    "Today" : "I dag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Noen hendelser i kalenderen er ødelagt. Vennligst sjekk JS konsollet for mer info.",
    "Share Calendar" : "Del kalender",
    "Shared" : "Delt",
    "More" : "Mer",
    "Edit" : "Rediger",
    "Link" : "Lenke",
    "iCal link" : "iCal-lenke",
    "Download" : "Last ned",
    "Share with users or groups" : "Del med brukere eller grupper",
    "can edit" : "kan endre",
    "Share link" : "Del lenke",
    "Public access" : "Offentlig tilgang",
    "Email link to person" : "Email lenke til person",
    "Send" : "Send",
    "New Calendar" : "Ny kalender",
    "Name" : "Navn",
    "New Subscription" : "Nytt abonnement",
    "Go back" : "Gå tilbake",
    "Go forward" : "Gå frem",
    "Calendar does not exist" : "Kalenderen finnes ikke",
    "Maybe you got a wrong link or the calendar was unshared?" : "Kanskje du fikk feil lenke eller kalenderen ikke er delt enda?",
    "Edit event" : "Rediger hendelse",
    "Delete Event" : "Slett hendelse",
    "Save Event" : "Lagre hendelse",
    "Time" : "Tid",
    "Type" : "Type",
    "Relative" : "Relativ",
    "Absolute" : "Absolutt",
    "Repeat" : "Gjenta",
    "times every" : "ganger hver",
    "Add" : "Legg til",
    "E-Mail address of attendee" : "E-postadresse for deltaker",
    "Please add your email address in the personal settings in order to add attendees." : "Legg inn epost-adressen din i personlige innstillinger for å kunne legge til deltakere.",
    "from" : "fra",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Hendelsens regel for gjentagelse støttes ikke ennå.",
    "Support for advanced rules will be added with subsequent updates." : "Støtte for avanserte regler blir lagt til i senere oppdateringer.",
    "Reset repeating rule" : "Nullstill gjentaksregel",
    "Repeat every ..." : "Gjenta hver…",
    "end repeat ..." : "avslutt gjentakelse…",
    "times" : "ganger",
    "Import Calendars" : "Importerer kalendre",
    "Import canceled" : "Import avbrutt",
    "Analyzing calendar" : "Analyserer kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen inneholder objekter som ikke passer sammen med den valgte kalenderen",
    "New calendar" : "Ny kalender",
    "File is empty" : "Filen er tom",
    "Import scheduled" : "Importer planlagte",
    "%s shared the calendar <strong>%s</strong> with you" : "%s delte kalenderen <strong>%s</strong> med deg",
    "Embed" : "Innebygg",
    "IFrame to integrate" : "Putt i iframe for å integrere",
    "Publish URL" : "Offentlig URL",
    "Settings & import" : "Innstillinger og import",
    "Skip simple event editor" : "Hopp over enkelt hendelsesredigering",
    "Show week numbers" : "Vis ukenumre",
    "Import calendar" : "Importer kalender",
    "No Calendars selected for import" : "Ingen kalendre valgt for import",
    "Primary CalDAV address" : "Primær CalDAV-adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse",
    "Subscribe" : "Abonner"
},
"nplurals=2; plural=(n != 1);");
